@@ -106,6 +106,34 @@ public abstract class ALLPerfTest extends ClassLoader {
                     + classes.size() + " classes = " + t + " ms");
         }
 
+        for (int i = 0; i < 10; ++i) {
+            long t = System.currentTimeMillis();
+            for (int j = 0; j < classes.size(); ++j) {
+                byte[] b = (byte[]) classes.get(j);
+                ClassReader cr = new ClassReader(b);
+                ClassWriter cw = new ClassWriter(cr, false);
+                cr.accept(cw, false);
+                cw.toByteArray();
+            }
+            t = System.currentTimeMillis() - t;
+            System.out.println("Time to deserialize and reserialize "
+                    + classes.size() + " classes (with copyPool) = " + t + " ms");
+        }
+        
+        for (int i = 0; i < 10; ++i) {
+            long t = System.currentTimeMillis();
+            for (int j = 0; j < classes.size(); ++j) {
+                byte[] b = (byte[]) classes.get(j);
+                ClassReader cr = new ClassReader(b);
+                ClassWriter cw = new ClassWriter(true);
+                cr.accept(cw, false);
+                cw.toByteArray();
+            }
+            t = System.currentTimeMillis() - t;
+            System.out.println("Time to deserialize and reserialize "
+                    + classes.size() + " classes (with computeMaxs) = " + t + " ms");
+        }
+
         for (int i = 0; i < 10; ++i) {
             long t = System.currentTimeMillis();
             for (int j = 0; j < classes.size(); ++j) {
